-- This file is a part of Avoision.
-- 
-- Copyright (C) 2011 Jared Krinke.
-- 
-- Avoision is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; either version 2
-- of the License, or (at your option) any later version.
-- 
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
-- 
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require("Avoision/Common.lua")

MovingObject = { }

function MovingObject.new(x, y, width, height, speedX, speedY)
    local movingObject = Entity.new(x, y, 0, width, height)

    movingObject.elements:add(Element.Image.new("Images/Block.png", 0, 0, 0, 1, 1))
    movingObject.mesh = Common.squareMesh
    movingObject.speed = { x = speedX, y = speedY }

    function movingObject.updateAxis(self, ms, axis, axisSize)
        local axisSpeed = self.speed[axis]
        local axisPosition = self[axis] + axisSpeed * ms

        if abs(axisPosition) + axisSize / 2 > 0.5 then
            -- Reverse direction
            if axisSpeed > 0 then
                axisPosition = 0.5 - axisSize / 2 - 0.01
            else
                axisPosition = -0.5 + axisSize / 2 + 0.01
            end

            self.speed[axis] = -axisSpeed

            Audio.play("Sounds/Bounce.wav", 1, self.x * 2)
        end

        self[axis] = axisPosition
    end

    function movingObject.update(self, ms)
        self:updateAxis(ms, "x", self.width)
        self:updateAxis(ms, "y", self.height)
    end

    return movingObject
end

