-- This file is a part of Avoision.
-- 
-- Copyright (C) 2012 Jared Krinke.
-- 
-- Avoision is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; either version 2
-- of the License, or (at your option) any later version.
-- 
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
-- 
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require("UI/UI.lua")
require("UI/Input.lua")
require("UI/Control.lua")
require("Utility/ForEach.lua")
require("Utility/SortedList.lua")
require("Utility/List.lua")

local logicalEvents = {
    "up",
    "down",
    "left",
    "right",
    "activate",
    "delete",
    "cancel",
}

local logicalEventNames = {
    up = "Menu Up",
    down = "Menu Down",
    left = "Move Left",
    right = "Move Right",
    activate = "Activate",
    delete = "Delete",
    cancel = "Cancel",
}

Controls = { }

function Controls.save()
    File.createDirectory("Settings")

    local file = File.openWrite("Settings/Controls.lua")

    file:write("controlsData = {")

    Table.forEach(Common.input:getRawToLogical(), function(rawEvent, logicalEvent)
        file:write(String.format("    [%q] = %q,", rawEvent, logicalEvent))
    end)

    file:write("}")
    file:close()
end

Common.input:addListener(Controls.save)

-- Controls menu
ControlsMenu = { }

function ControlsMenu.new()
    local controlsForm = Form.newGrid(1)

    -- UI
    controlsForm:add(Title.new("Controls"))
    controlsForm:add(Separator.new())

    -- Add controls
    local i = 1

    while not isNil(logicalEvents[i]) do
        local logicalEvent = logicalEvents[i]

        controlsForm:add(Control.new(Common.input, logicalEvent, logicalEventNames[logicalEvent]))
        i = i + 1
    end

    controlsForm:add(Separator.new())
    controlsForm:add(Button.new("Back", function() Layers.pop() end))

    return FormLayer.new(controlsForm)
end

