-- This file is a part of Avoision.
-- 
-- Copyright (C) 2012 Jared Krinke.
-- 
-- Avoision is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; either version 2
-- of the License, or (at your option) any later version.
-- 
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
-- 
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require("Avoision/Common.lua")
require("Effects/ScriptedEntity.lua")

local textSizeFactor = 3 / 4
local textWidth = Common.textWidth * textSizeFactor
local textHeight = Common.textHeight * textSizeFactor
local lines = 480 / textHeight
local visiblePeriod = 11000
local delayFactor = visiblePeriod / lines

CreditsMenu = {
    credits = {
        "Avoision " .. Common.version,
        "http://avsn.sourceforge.net/",
        "",
        "Development",
        "",
        "Game Design                 Jared Krinke",
        "   http://radius-engine.sourceforge.net/",
        "",
        "Programming                 Jared Krinke",
        "",
        "Art",
        "",
        'Music          "Spelunking for Pleasure"',
        "                    by Nicholas Heinlein",
        "                            (Lada Laika)",
        "        http://www.myspace.com/ladalaika",
        "",
        "Graphics                    Jared Krinke",
        "",
        "Sound Effects               Jared Krinke",
        "",
        "Testing                   Iwan Gabovitch",
        "                             qubodup.net",
        "",
        "Technology",
        "",
        "Radius Engine               Jared Krinke",
        "",
        "SDL                         Sam Lantinga",
        "                  http://www.libsdl.org/",
        "",
        "Lua                              PUC-Rio",
        "                     http://www.lua.org/",
        "",
        "SDL_sound                    Ryan Gordon",
        "           http://icculus.org/SDL_sound/",
        "",
        "PhysicsFS                    Ryan Gordon",
        "              http://icculus.org/physfs/",
        "",
        "Licensing",
        "",
        "Avoision's source code is distributed   ",
        "under the terms of the GNU General      ",
        "Public License (version 2 or later). For",
        "complete details (e.g. copyright date), ",
        "see each source code file or the full   ",
        "text of the license in License.txt.     ",
        "",
        "Avoision's graphics and sound effects   ",
        "are copyright (C) 2010 Jared Krinke and ",
        "are distributed under the terms of the  ",
        "Creative Commons Attribution-ShareAlike ",
        "3.0 Unported License. To view a copy of ",
        "this license, visit                     ",
        "http://creativecommons.org/licenses/    ",
        "by-sa/3.0/ or send a letter to Creative ",
        "Commons, 171 Second Street, Suite 300,  ",
        "San Francisco, California, 94105, USA.  ",
        "",
        "Avoision's background music is          ",
        '"Spelunking for Pleasure" by Lada Laika.',
        "The work is copyright (C) 2009          ",
        "Nicholas Heinlein and is licensed under ",
        "the terms of the Creative Commons       ",
        "Attribution-ShareAlike 3.0 Unported     ",
        "License. To view a copy of this license,",
        "visit http://creativecommons.org/       ",
        "licenses/by-sa/3.0/ or send a letter to ",
        "Creative Commons, 171 Second Street,    ",
        "Suite 300, San Francisco, California,   ",
        "94105, USA.                             ",
    },
}

local eventToPop = {
    activate = true,
    cancel = true,
}

function CreditsMenu.new()
    local creditsMenu = Layer.new(33)

    function creditsMenu.inputReceived(self, event, pressed)
        if pressed then
            local pop = eventToPop[event]

            if isBoolean(pop) and pop then
                Layers.pop()
            end
        end
    end

    function creditsMenu.show(self)
        local i = 1

        self:clearChildren()

        while i <= #CreditsMenu.credits do
            local text = CreditsMenu.credits[i]

            if isString(text) and text ~= "" then
                self:addChild(ScriptedEntity.new({ Element.Text.new(text, 0, 0, 0, 1, 1, 0, Color.new(1, 1, 1), "center") },
                                                 { { 0,                               0, -240 - i * textHeight, 0, textWidth, textHeight, 0, Color.new(1, 1, 1) },
                                                   { visiblePeriod + i * delayFactor, 0, 240 + textHeight,  0, textWidth, textHeight, 0, Color.new(1, 1, 1) } },
                                                 true,
                                                 function(entity) self:removeChild(entity) end))
            end

            i = i + 1
        end

        Layers.push(self)
    end

    Common.input:setupEventHandlers(creditsMenu)

    return creditsMenu
end


